SimpleSidebarItem class

Constructors

SimpleSidebarItem({required String title, IconData? leading, Widget? leadingWidget, Function? onTap})

Properties

hashCode → int
The hash code for this object.
no setterinherited
leading ↔ IconData?
getter/setter pair
leadingWidget ↔ Widget?
getter/setter pair
onTap ↔ Function?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited